# Makefile for Buckets v1.00 - chaotic water wheel simulator
# Copyright (C) 1994  Tony Smith-Grieco
#
# This program is free software.  See the file COPYING for details.
#
#
# This is a makefile for Turbo C++ v1.01.
# It should be easily ported to other compilers and other Make programs.

# This line tells the Turbo C++ Make to do autodependency checking.
# It will look at the .OBJ files for the date and time of the header files
# which were included in that source files, and re-compile the source file
# if the header files have been modified since the last compilation.
.AUTODEPEND


MAKEFILE = buckets.mak


# locations of compiler, linker, header files, libraries, etc.

BINDIR = h:\bin
INCDIR = h:\include
LIBDIR = h:\lib


# compiler/linker options
#
# GR           specifies whether or not to do any graphics at all.
#              Useful mainly if you would just like to track the
#              variables - it's easier in text mode.
#

COMPDEFS = -DGR
COMPOPT = $(COMPDEFS)


# Indicates where the compiler, linker and assembler are.
# (You know, those unimportant little binaries).
#

CC = $(BINDIR)\tcc +BUCKETS.CFG $(COMPOPT)
ASM = $(BINDIR)\TASM
LINK = $(BINDIR)\tlink


#		*Implicit Rules*

.c.obj:
  $(CC) -c {$< }

.cpp.obj:
  $(CC) -c {$< }

.asm.obj:
  $(ASM) {$< }


#		*List Macros*

EXE_dependencies =  \
  buckets.obj


#		*Explicit Rules*
#
# The options given to the linker are as follows, if you are worried
# about linker problems when porting to another compiler:
#
#    /x   Don't generate any kind of map file
#         This option does not affect at the program at all.
#
#    /c   Case-sensitive linking
#         My guess is that this is very important and necessary, but
#         I'm not a real expert on the linking process, so don't take
#         my word for it.
#
# The libraries are as follows:
#
# c0s.obj		startup module for small memory model
# graphics.lib	library for graphics routines (surprise surprise)
# emu.lib		floating-point emulation
# maths.lib	math stuff for small memory model
# cs.lib		the main library for small memory model

# The '&&|' tells the Make program to take everything up until the next |
# symbol and put it into a temporary file.  The name of the temporary file
# then replaces the '&&|' on the command line.  So in this particular case,
# whatever text is in between &&| and | is placed inside a temporary file,
# and the command line becomes something like:
#    $(LINK) /v/x/c @tempfile.cfg
#
# In turn, the linker sees the '@' symbol and interprets the contents of
# tempfile.cfg as instructions that tell it what to do.
#

buckets.exe: buckets.cfg $(EXE_dependencies)
  $(LINK) /x /c @&&|
h:\lib\c0s.obj+
buckets.obj
buckets,
h:\lib\graphics.lib+
h:\lib\emu.lib+
h:\lib\maths.lib+
h:\lib\cs.lib
|


#		*Individual File Dependencies*

buckets.obj: buckets.c $(MAKEFILE)


#		*Compiler Configuration File*
#
# In case you are trying to port this to another compiler, this is what
# these options do.
#
# This is the only absolutely necessary option:
#  -K   make 'char' unsigned by default
#
# These are optional:
#  -G   optimize for speed
#  -O	optimize jumps
#  -Z	enable register usage optimization 
#
# These might have to be changed to suit your compiler:
#  -I	specify directories to look for include files
#  -L	specify directories to look for libraries

# (The '&&|' business is explained in the '*Explicit Rules*' section if
#  it is unfamiliar to you.)

buckets.cfg: $(MAKEFILE)
  copy &&|
-K
-G
-O
-Z
-I$(INCDIR)
-L$(LIBDIR)
| buckets.cfg

#
# Turbo C++ is a trademark of Borland International.
#
